summaryrefslogtreecommitdiffstats
path: root/kplato/kptdatetable.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kplato/kptdatetable.cc')
-rw-r--r--kplato/kptdatetable.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/kplato/kptdatetable.cc b/kplato/kptdatetable.cc
index 44f91500..2fc19d4f 100644
--- a/kplato/kptdatetable.cc
+++ b/kplato/kptdatetable.cc
@@ -175,7 +175,7 @@ void DateTable::paintWeekNumber(TQPainter *painter, int row) {
painter->drawRect(0, 0, w, h);
painter->setPen(KGlobalSettings::textColor());
- painter->drawText(0, 0, w, h-1, AlignCenter, TQString("%1").tqarg(m_weeks[row].first), -1, &rect);
+ painter->drawText(0, 0, w, h-1, AlignCenter, TQString("%1").arg(m_weeks[row].first), -1, &rect);
painter->setPen(colorLine);
painter->moveTo(w-1, 0);
painter->lineTo(w-1, h-1);
@@ -527,7 +527,7 @@ bool DateTable::selectDate(const TQDate& date_) {
return true;
}
-bool DateTable::setDate(const TQDate& date_, bool tqrepaint) {
+bool DateTable::setDate(const TQDate& date_, bool repaint) {
//kdDebug()<<k_funcinfo<<"date="<<date_.toString()<<endl;
bool changed=false;
TQDate temp;
@@ -562,7 +562,7 @@ bool DateTable::setDate(const TQDate& date_, bool tqrepaint) {
m_selectedDates.insert(date);
}*/
numDaysPrevMonth=temp.daysInMonth();
- if(changed && tqrepaint) {
+ if(changed && repaint) {
repaintContents(false);
}
if (m_enabled)
@@ -894,7 +894,7 @@ DateInternalMonthPicker::contentsMouseMoveEvent(TQMouseEvent *e)
updateCell( row, col /*, false */ ); // mark the new active cell
}
}
- if ( tmpRow > -1 ) // tqrepaint the former active cell
+ if ( tmpRow > -1 ) // repaint the former active cell
updateCell( tmpRow, tmpCol /*, true */ );
}
}
@@ -1053,7 +1053,7 @@ int
PopupFrame::exec(TQPoint pos)
{
popup(pos);
- tqrepaint();
+ repaint();
tqApp->enter_loop();
hide();
return result;